/*
 *  Copyright 2008, Javid Jamae and Peter Johnson
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License"); you may not
 *  use this file except in compliance with the License. You may obtain a copy
 *  of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *  
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 *  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 *  License for the specific language governing permissions and limitations
 *  under the License.
 */
package com.objis.demoejb3mdb.client;

import java.util.Date;

import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.Destination;
import javax.jms.MessageProducer;
import javax.jms.ObjectMessage;
import javax.jms.Session;
import javax.naming.Context;
import javax.naming.InitialContext;

import domaine.DemandeFormation;

/**
 * Messaging client class that represents a customer in the video store example
 * application.
 */
public class ClientJMS {

	// Session tablie avec le serveur.
	private Session session;

	// Le client utilise un Producteur de messsage pour envoyer une demande de
	// formation
	private MessageProducer producer;

	public boolean envoi(String client) throws Exception {

		Connection connection = null;
		try {

			// Cration ConnectionFactory et Destination JMS
			Context initial = new InitialContext();
			ConnectionFactory cf = (ConnectionFactory) initial.lookup("ConnectionFactory");
			Destination destination = (Destination) initial.lookup("/topic/DemandeFormation");

			// Cration Connection et Session JMS
			connection = cf.createConnection("guest", "guest");
			connection.setClientID(client);
			session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);

			// Cre le producteur utilis pour envoyer un message:
			producer = session.createProducer(destination);

			// Lancer la connection
			connection.start();

			DemandeFormation demandeFormation = new DemandeFormation();
			demandeFormation.setThemeFormation("EJB3");
			demandeFormation.setAdresseParticipant("4 allee des cerisiers");
			demandeFormation.setSocieteParticipant("TechSoft");
			demandeFormation.setNomParticipant("Jean Dupont");
			demandeFormation.setRemarqueParticipant("Merci");
			demandeFormation.setEmailParticipant("jean.dupont@techsoft.com");
			demandeFormation.setAudit("oui");
			demandeFormation.setDateDebut(new Date());

			ObjectMessage om = session.createObjectMessage(demandeFormation);

			producer.send(om);

		} catch (Exception e) {
			e.printStackTrace();
		} finally {

			/*
			 * Fermeture de la connection , Sinon Jboss Messagingpas content.
			 */
			if (connection != null) {
				session.close();
				connection.close();
			}
		}
		return true;
	}

	/**
	 * Point d'entre.
	 * 
	 * @throws Exception
	 *             Qqchse de pas cool arrive.
	 */
	public static void main(String[] args) throws Exception {

		new ClientJMS().envoi("guest");
	}
}
